An implementation of the Language Server Protocol for R. The Language Server protocol is used by an editor client to integrate features like auto completion. See https://microsoft.github.io/language-server-protocol/ for details.
Maintainer: Randy Lai [email protected]
Authors:
Randy Lai [email protected]
Other contributors:
Kun Ren [email protected] [contributor]
An implementation of the Language Server Protocol for R
Useful links: